CORS¶
Plone offers CORS handling with the plone.rest package. CORS configuration is needed if you want to access the Plone REST API from a different domain than the one Plone is running on.
Setting |
Default |
Allowed Values |
|---|---|---|
|
|
|
|
|
|
|
|
comma-separated list |
|
|
comma-separated list |
|
|
comma-separated origins or |
|
|
comma-separated list |
|
|
integer (seconds) |
cors_allow_origin – Origins that are allowed access to the resource. Either a comma separated list of origins, e.g. https://example.com,https://otherexample.com, or * for all.